DataGroup class abstract

Inheritance
Implementers

Constructors

DataGroup.fromBytes(Uint8List data)

Properties

fid int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sfi int
no setterinherited
tag int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(Uint8List content) → void
override
parseContent(Uint8List content) → void
toBytes() Uint8List
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited