EfCOM class

Inheritance

Constructors

EfCOM.fromBytes(Uint8List data)

Properties

dgTags Set<DgTag>
no setter
fid int
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sfi int
no setteroverride
unicodeVersion → dynamic
no setter
version → dynamic
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(Uint8List content) → void
override
toBytes() Uint8List
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

FID → const int
SFI → const int
TAG → const int