dmrtd library
Classes
- AAPublicKey
- AccessKey
- ComProvider
- Abstract interface for communicating with ICC.
- DataGroup
- DBAKey
- Class defines Document Basic Access Keys as specified in section 9.7.2 of doc ICAO 9303 p11 which are used to establish secure messaging session via BAC protocol.
- DecodedLen
- Decoded len
- DecodedTag
- Decoded tag
- DecodedTL
- Decoded tag and value length
- DecodedTV
- Decoded tag and value
- DgTag
- EfCardAccess
- EfCardSecurity
- EfCOM
- EfDG1
- EfDG10
- EfDG11
- EfDG12
- EfDG13
- EfDG14
- EfDG15
- EfDG16
- EfDG2
- EfDG3
- EfDG4
- EfDG5
- EfDG6
- As specified in ICAO9303-p10 is not used and reserved for future.
- EfDG7
- EfDG8
- EfDG9
- EfSOD
- ElementaryFile
- MRZ
- NfcProvider
- Passport
- TLV
- Class Represents BER-TLV encoding/decoding functions.
- TLVEmpty
Constants
- SEED_LEN_BAC → const int
- SEED_LEN_PACE → const int
Exceptions / Errors
- ComProviderError
- EfParseError
- MRZParseError
- NfcProviderError
- PassportError
- TLVError
- Thrown when tag and data can't be encoded or decoded.